# langchain-azure-storage

This package contains the LangChain integrations for Azure Storage. This project is a work-in-progress and currently does not contain any features.

## Installation

```bash
pip install -U langchain-azure-storage
```
